==> links_v0.7.0b.tar.gz: links/system/system.class.php <==
<?php
/////////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------
//                        Syatem class for Links Ver0.7
//                    Copyright (C) 2002-2003  WHITEWING,Team-act
//             <Mail: whitewing@w-wing.net> <URL: http://w-wing.net/>
//--------------------------------------------------------------------
//
//This program is free software; you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation; either version 2 of the License, or
//(at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//////////////////////////////////////////////////////////////////////////////

define("_Version","Ver0.7.0 beta");

class find_ctgy{
 var $find;
  function find_ctgy($no){
  $this->find=NULL;
  $fp=@fopen(_Def_Site,"r");
  if($fp){
   while($dat=fgetcsv($fp,8192,"\t")){
    if($dat[0]==$no){
     $this->find=$dat[1];
     break;
    }
   }
   fclose($fp);
  }
 return($this->find);
 }
}

class ut2jt{
 var $jt;
  function ut2jt($ut){
   $week=array("Sun","Mon","Tue","Wed","Thu","Fri","Sat");
   $this->jt= $ut + _JISA ;
   $this->jt =( date("Y/m/d H:i:s",$this->jt)."(".$week[date("w",$this->jt)].")" );
   return ;
  }
}

class create_pn{
 var $prev; var $next;
  function create_pn(){
  $tmp=$_GET["page"];
  
   if($_GET["page"] >= 2){
    $tmp--;
    $this->prev='<a href="index.php?ctgy='.$_GET["ctgy"].'&page='.$tmp.'">'. _Prev .'</a>';
    $tmp++;
   }
   else{$this->prev = _Prev ;}

   $fp=@fopen("./data/".$_GET["ctgy"].".cgi","r");
   if($fp){
    while ($dat=fgetcsv($fp,16384)){$i++;}
    if($i <= $_GET["page"] * _PV){
    $tmp++;
    $this->next='<a href="index.php?ctgy='.$_GET["ctgy"].'&page='.$tmp.'">'. _Next .'</a>';
    }
    else{$this->next= _Next ;}
   }
  return ;
  }
}

function ctg_name(){
 $fp=@fopen(_Def_Ctgy,"r");
 if($fp){
  flock($fp,LOCK_SH);
  while($dat=fgetcsv($fp,8192,"\t")){
   if($dat[0]==$_GET["ctgy"]){$rt=$dat[1];break;}
  }
  flock($fp,LOCK_UN);
  fclose($fp);
  if($dat==flase){$rt=&$dat;}
 }
 else{$rt=false;}
return $rt;
}

function nochk(){
 $fp = @fopen(_Def_New,"r");
  if($fp){
   $buf = fgets($fp,4096);
   $no_data=(strtok($buf,"\t"));
   fclose($fp);
   if(!$no_data){$no_data=0;}
   $no_data++;
  }
  else{
  $no_data=FALSE;
  }
 return $no_data;
}

function nw(){
 switch (_Tag){
  case 0: $comment=htmlspecialchars($_POST["comment"]);break;
  case 1: $comment = $_POST["comment"]; break;
  case 2:
  default: $comment=strip_tags($_POST["comment"]);break;
 }
 if(_Auto_link){
  $comment = ereg_replace("(https?|ftp|news)(://[[:alnum:]\+\$\;\?\.%,!#~*/:@&=_-]+)","<a href=\"\\1\\2\" target=\"_blank\">\\1\\2</a>",$comment);
 }
 $comment = str_replace("\r\n", "\r", $comment);
 $comment = str_replace("\r", "\n", $comment);
 _Br ? $comment = str_replace("\n", "<br />", $comment) : $comment = str_replace("\n", "", $comment) ;
 $comment = str_replace("<br>","<br />",$comment);
 $title = strip_tags($_POST["title"]);
 $title = htmlspecialchars($title);
 $url = strip_tags($_POST["url"]);
 $no=nochk();
 $gmq=get_magic_quotes_gpc();
 if(_MQ && $gmq){
  $comment=stripslashes($comment);
  $title=stripslashes($title);
  $title=addcslashes($title,"\"");
  $comment=addcslashes($comment,"\"");
 }
 $time=time()-date("Z");
 $pass=md5($_POST["pass"]);
 if($_POST["burl"] == "" || $_POST["burl"] == "http://"){
 $burl=_No_Banner;
 }
 else{$burl=$_POST["burl"];}
 return array($no,$url,$burl,$title,$comment,$time,$pass);
}

//Exception Handling function
function exception(){
  if(_Proxy && $_SERVER["HTTP_VIA"]){
  echo("You don't permit to write!! Why? Now Proxy block mode!");
  exit;
  }
  if(!$_POST["title"] or !$_POST["url"] or $_POST["url"]=="http://" or !$_POST["catg"] or !$_POST["comment"] or !$_POST["pass"]){
  echo("Please fill all in.(Exception 'Banner URL')");
  exit;
  }
  if(_Ref_Check &&$_SERVER["HTTP_REFERER"]!="http://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"]){
  echo("Unjust writing!!");
  exit;
  }
  $path="./data/".$_POST["catg"].".cgi";
  if(file_exists($path)==FALSE){
  echo("Such category not exist!!");
  sleep(3);
  header("Location: ./index.php");
  exit;
  }
  return;
}

function regist($file,$msgstr,$flag=FALSE){
 $templog= file($file);
 if(!$fp=@fopen($file,"w")){
  return FALSE;
 }
 flock($fp,LOCK_EX);
 fputs($fp,$msgstr);
 if($flag){
  $i=0;
  foreach ($templog as $linelog){
   if(++$i < _VP){fputs($fp,$linelog);}
   else {break;}
  }
 }
 else{
  foreach ($templog as $linelog){
   fputs($fp,$linelog);
  }
 }
 flock($fp,LOCK_UN);
 fclose($fp);
 return TRUE;
}

function mail_to_admin($title,$url,$burl){
 $message= "'".$title."' is registered.\n\nURL: ".$url."\nBanner URL: ".$burl;
 mb_language(_Mb_Lang);
 mb_send_mail(_Admin_mail , $title." is registered",$message,
   "From: webmaster@".$_SERVER["HTTP_HOST"]."\r\n"
   ."Reply-To: webmaster@".$_SERVER["HTTP_HOST"]."\r\n"
   ."X-Mailer: PHP/" . phpversion()
 );
 return;
}

function banner_upload(){
 if($_FILES["bup"]["tmp_name"] && is_uploaded_file($_FILES["bup"]["tmp_name"])){
  switch ($_FILES["bup"]["type"]){
   case "image/gif"   : $ex= ".gif"; break;
   case "image/jpeg"  : $ex= ".jpg"; break;
   case "image/x-png" : $ex= ".png"; break;
  default            : exit("Error extension!!"); break;
  }
  $no=sprintf("%05d",nochk());
  $b_path="./banner/".$no.$ex;
  if(!copy($_FILES["bup"]["tmp_name"],$b_path)){
   exit("Copy failed!");
  }
 }
 else{$b_path=NULL;}
 return $b_path;
}

function delete_no($file){
 $templog=file($file);
 if(!$fp=fopen($file,"w")){
  return FALSE;
 }
 flock($fp,LOCK_EX);
 foreach($templog as $linelog){
  $dat = explode("\t",$linelog);
  if($dat[0] != $_POST["no"]){
   fputs($fp,$linelog);
  }
 }
 flock($fp,LOCK_UN);
 fclose($fp);
 return TRUE;
}

function rewrite($file,$msg,$flag=FALSE){
 $templog = file($file);
 if(!$templog){$templog[0]=NULL;}
 if(!$fp=@fopen($file,"w")){
  return FALSE;
 }
 flock($fp,LOCK_EX);
 if($flag){
  foreach($templog as $linelog){
   $dat = explode("\t",$linelog);
   if(($dat[0] < $_POST["no"]) && !defined(Rewrite)){
    fputs($fp,$msg);
    define("Rewrite",1);
   }
   fputs($fp,$linelog);
  }
  if(!defined("Rewrite")){fputs($fp,$msg);}
 }
 else{
  foreach ($templog as $linelog){
   $dat = explode("\t",$linelog);
   if($dat[0]==$_POST["no"]){
    fputs($fp,$msg);
   }
   else{
    fputs($fp,$linelog);
   }
  }
 }
 flock($fp,LOCK_UN);
 fclose($fp);
}

function pass_check($path,$pass){
  if(!$fp=@fopen($path,"r")){
   return FALSE;
  }
  flock($fp,LOCK_SH);
  while($dat=fgetcsv($fp,16384,"\t")){
   if($dat[0]==$_POST["no"]){break;}
  }
  flock($fp,LOCK_UN);
  fclose($fp);

  if($dat[5]!=md5($pass)){
   echo("Password Failed");
   exit;
  }
  return TRUE;
}
?>

==> links_v0.7.2b.tar.gz: links/system/system.class.php <==
<?php
/////////////////////////////////////////////////////////////////////////////
//--------------------------------------------------------------------
//                        Syatem class for Links Ver0.7
//                    Copyright (C) 2002-2003  WHITEWING,Team-act
//             <Mail: whitewing@w-wing.net> <URL: http://w-wing.net/>
//--------------------------------------------------------------------
//
//This program is free software; you can redistribute it and/or modify
//it under the terms of the GNU General Public License as published by
//the Free Software Foundation; either version 2 of the License, or
//(at your option) any later version.
//
//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU General Public License for more details.
//
//You should have received a copy of the GNU General Public License
//along with this program; if not, write to the Free Software
//Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//////////////////////////////////////////////////////////////////////////////

define("_Version","Ver0.7.2 beta");

class find_ctgy{
 var $find;
  function find_ctgy($no){
  $this->find=NULL;
  $fp=@fopen(_Def_Site,"r");
  if($fp){
   while($dat=fgetcsv($fp,8192,"\t")){
    if($dat[0]==$no){
     $this->find=$dat[1];
     break;
    }
   }
   fclose($fp);
  }
 return($this->find);
 }
}

class ut2jt{
 var $jt;
  function ut2jt($ut){
   $week=array("Sun","Mon","Tue","Wed","Thu","Fri","Sat");
   $this->jt= $ut + _JISA ;
   $this->jt =( date("Y/m/d H:i:s",$this->jt)."(".$week[date("w",$this->jt)].")" );
   return ;
  }
}

class create_pn{
 var $prev; var $next;
  function create_pn(){
  $tmp=$_GET["page"];
  
   if($_GET["page"] >= 2){
    $tmp--;
    $this->prev='<a href="index.php?ctgy='.$_GET["ctgy"].'&page='.$tmp.'">'. _Prev .'</a>';
    $tmp++;
   }
   else{$this->prev = _Prev ;}

   $fp=@fopen("./data/".$_GET["ctgy"].".cgi","r");
   if($fp){
    while ($dat=fgetcsv($fp,16384)){$i++;}
    if($i <= $_GET["page"] * _PV){
    $tmp++;
    $this->next='<a href="index.php?ctgy='.$_GET["ctgy"].'&page='.$tmp.'">'. _Next .'</a>';
    }
    else{$this->next= _Next ;}
   }
  return ;
  }
}

function ctg_name(){
 $fp=@fopen(_Def_Ctgy,"r");
 if($fp){
  flock($fp,LOCK_SH);
  while($dat=fgetcsv($fp,8192,"\t")){
   if($dat[0]==$_GET["ctgy"]){$rt=$dat[1];break;}
  }
  flock($fp,LOCK_UN);
  fclose($fp);
  if($dat==flase){$rt=&$dat;}
 }
 else{$rt=false;}
return $rt;
}

function nochk(){
  if($fp = @fopen(_Def_New,"r")){
   $buf = fgets($fp,4096);
   $no_data=(strtok($buf,"\t"));
   fclose($fp);
   if(!$no_data){$no_data=0;}
   $no_data++;
  }
  else { $no_data=FALSE; }
 return $no_data;
}

class nw_c{
 var $no;
 var $url;
 var $burl;
 var $title;
 var $comment;
 var $time;
 var $pass;
 function nw_c(){
  //Comment
  switch (_Tag){
   case 0: $this->comment=htmlspecialchars($_POST["comment"]);break;
   case 1: $this->comment = $_POST["comment"]; break;
   case 2:
   default: $this->comment=@strip_tags($_POST["comment"]);break;
  }
  $this->comment = str_replace("\r\n", "\r", $this->comment);
  $this->comment = str_replace("\r", "\n", $this->comment);
  _Br ? $this->comment = str_replace("\n", "<br />", $this->comment) : $this->comment = str_replace("\n", "", $this->comment) ;
  $this->comment = str_replace("<br>","<br />",$this->comment);
  $this->title = htmlspecialchars($_POST["title"]);
  $this->pass=md5($_POST["pass"]);
  $this->no=nochk();
  $this->time=time()-date("Z");
  $this->url = strip_tags($_POST["url"]);
  if($_POST["burl"] == "" || $_POST["burl"] == "http://"){ $this->burl=_No_Banner; }
  else{$this->burl=$_POST["burl"];}

  return;
 }
 function set_burl($set_value){
  $this->burl=$set_value;
  return;
 }
}

function create_ctgy_menu(&$tmpl){
 if(!$fp=@fopen(_Def_Ctgy,"r")){ exit("Failed to open file('". _Def_Ctgy ."')"); }
 flock($fp,LOCK_SH);
 $tmpl->loopset("Menu");
 if($_GET["ctgy"] or $_GET["no"]){
  $tmpl->assign("ctg_name",_Latest);
  $tmpl->assign("ctg_unix","");
  $tmpl->loopnext("Menu");
 }
 while($ctg_dat=fgetcsv($fp,8192,"\t")){
  if(($ctg_dat[0]!=$_GET["ctgy"])){	
   $tmpl->assign("ctg_unix",$ctg_dat[0]);
   $tmpl->assign("ctg_name",$ctg_dat[1]);
   $tmpl->loopnext("Menu");
  }
 }
 $tmpl->loopend("Menu");
 flock($fp,LOCK_UN);
 fclose($fp);
 return ;
}

//Exception Handling function
function exception(){
  if(_Proxy && $_SERVER["HTTP_VIA"]){
  echo("You don't permit to write!! Why? Now Proxy block mode!");
  exit;
  }
  if(!$_POST["title"] or !$_POST["url"] or $_POST["url"]=="http://" or !$_POST["catg"] or !$_POST["comment"] or !$_POST["pass"]){
  echo("Please fill all in.(Exception 'Banner URL')");
  exit;
  }
  if(_Ref_Check &&$_SERVER["HTTP_REFERER"]!="http://".$_SERVER["HTTP_HOST"].$_SERVER["REQUEST_URI"]){
  echo("Unjust writing!!");
  exit;
  }
  $path="./data/".$_POST["catg"].".cgi";
  if(file_exists($path)==FALSE){
  echo("Such category not exist!!");
  sleep(3);
  header("Location: ./index.php");
  exit;
  }
  return;
}

function regist($file,$msgstr,$flag=FALSE){
 $templog= file($file);
 if(!$fp=@fopen($file,"w")){
  return FALSE;
 }
 flock($fp,LOCK_EX);
 fputs($fp,$msgstr);
 if($flag){
  $i=0;
  foreach ($templog as $linelog){
   if(++$i < _VP){fputs($fp,$linelog);}
   else {break;}
  }
 }
 else{
  foreach ($templog as $linelog){
   fputs($fp,$linelog);
  }
 }
 flock($fp,LOCK_UN);
 fclose($fp);
 return TRUE;
}

function mail_to_admin($title,$url,$burl){
 $message= "'".$title."' is registered.\n\nURL: ".$url."\nBanner URL: ".$burl;
 mb_language(_Mb_Lang);
 mb_send_mail(_Admin_mail , $title." is registered",$message,
   "From: webmaster@".$_SERVER["HTTP_HOST"]."\r\n"
   ."Reply-To: webmaster@".$_SERVER["HTTP_HOST"]."\r\n"
   ."X-Mailer: PHP/" . phpversion()
 );
 return;
}

function banner_upload(){
 if($_FILES["bup"]["tmp_name"] && is_uploaded_file($_FILES["bup"]["tmp_name"])){
  switch ($_FILES["bup"]["type"]){
   case "image/gif"   : $ex= ".gif"; break;
   case "image/jpeg"  : $ex= ".jpg"; break;
   case "image/x-png" : $ex= ".png"; break;
  default            : exit("Error extension!!"); break;
  }
  $no=sprintf("%05d",nochk());
  $b_path="./banner/".$no.$ex;
  if(!copy($_FILES["bup"]["tmp_name"],$b_path)){
   exit("Copy failed!");
  }
 }
 else{$b_path=NULL;}
 return $b_path;
}

function delete_no($file){
 $templog=file($file);
 if(!$fp=fopen($file,"w")){
  return FALSE;
 }
 flock($fp,LOCK_EX);
 foreach($templog as $linelog){
  $dat = explode("\t",$linelog);
  if($dat[0] != $_POST["no"]){
   fputs($fp,$linelog);
  }
 }
 flock($fp,LOCK_UN);
 fclose($fp);
 return TRUE;
}

function rewrite($file,$msg,$flag=FALSE){
 $templog = file($file);
 if(!$templog){$templog[0]=NULL;}
 if(!$fp=@fopen($file,"w")){
  return FALSE;
 }
 flock($fp,LOCK_EX);
 if($flag){
  foreach($templog as $linelog){
   $dat = explode("\t",$linelog);
   if(($dat[0] < $_POST["no"]) && !defined("Rewrite")){
    fputs($fp,$msg);
    define("Rewrite",1);
   }
   fputs($fp,$linelog);
  }
  if(!defined("Rewrite")){fputs($fp,$msg);}
 }
 else{
  foreach ($templog as $linelog){
   $dat = explode("\t",$linelog);
   if($dat[0]==$_POST["no"]){
    fputs($fp,$msg);
   }
   else{
    fputs($fp,$linelog);
   }
  }
 }
 flock($fp,LOCK_UN);
 fclose($fp);
}

function pass_check($path,$pass){
  if(!$fp=@fopen($path,"r")){
   return FALSE;
  }
  flock($fp,LOCK_SH);
  while($dat=fgetcsv($fp,16384,"\t")){
   if($dat[0]==$_POST["no"]){break;}
  }
  flock($fp,LOCK_UN);
  fclose($fp);

  if($dat[5]!=md5($pass)){
   echo("Password Failed");
   exit;
  }
  return TRUE;
}

function regist_ctgy(&$tmpl,$target){
 if(!$fp=@fopen(_Def_Ctgy,"r")){
  echo("Failed to open file('". _Def_Ctgy ."')");
  exit;
 }
 flock($fp,LOCK_SH);
 $tmpl->loopset($target);
 while ($ctg_dat=fgetcsv($fp,16384,"\t")){
  $tmpl->assign("ctg_unix",$ctg_dat[0]);
  $tmpl->assign("ctg_name",$ctg_dat[1]);
  $tmpl->loopnext($target);
 }
 $tmpl->loopend($target);
 flock($fp,LOCK_UN);
 fclose($fp);
}

?>
